@@ -14,8 +14,8 @@ pool = ConnectionPool(factory=Connection, backend="eventlet")
 epool = eventlet.GreenPool()
 
 urls = [
-        "http://yahoo.fr",
-        "http://google.com",
+        "http://refuge.io",
+        "http://gunicorn.org",
         "http://friendpaste.com",
         "http://benoitc.io",
         "http://couchdb.apache.org"]
