@@ -12,9 +12,7 @@ import tempfile
 
 dirname = os.path.dirname(__file__)
 
-from restkit.http.parser import RequestParser
-
-from restkit.client import HttpRequest
+from restkit.client import Client
 from restkit.resource import Resource
 
 from _server_test import HOST, PORT, run_server_test
@@ -27,17 +25,6 @@ def data_source(fname):
             line = line.rstrip("\n").replace("\\r\\n", "\r\n")
             buf.write(line)
         return buf
-
-class request(object):
-    def __init__(self, name):
-        self.fname = os.path.join(dirname, "requests", name)
-        
-    def __call__(self, func):
-        def run():
-            src = data_source(self.fname)
-            func(src, RequestParser(src))
-        run.func_name = func.func_name
-        return run
         
         
 class FakeSocket(object):
@@ -74,8 +61,7 @@ class FakeSocket(object):
                 
 class client_request(object):
     
-    def __init__(self, path, pool=False):
-        self.pool = pool
+    def __init__(self, path):
         if path.startswith("http://") or path.startswith("https://"):
             self.url = path
         else:
@@ -83,11 +69,7 @@ class client_request(object):
         
     def __call__(self, func):
         def run():
-            if self.pool:
-                pool_instance = ConnectionPool()
-            else:
-                pool_instance = None
-            cli = HttpRequest(pool_instance=None, timeout=0.5)
+            cli = Client(timeout=300)
             func(self.url, cli)
         run.func_name = func.func_name
         return run
